<?php

namespace Superrobota\Insurance\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Insurance\Models\Insurance;

class InsurancePolicy
{

    /**
     * Determine if the given user can view the insurance.
     *
     * @param UserPolicy $user
     * @param Insurance $insurance
     *
     * @return bool
     */
    public function view(UserPolicy $user, Insurance $insurance)
    {
        if ($user->canDo('insurance.insurance.view') && $user->isAdmin()) {
            return true;
        }

        return $insurance->user_id == user_id() && $insurance->user_type == user_type();
    }

    /**
     * Determine if the given user can create a insurance.
     *
     * @param UserPolicy $user
     * @param Insurance $insurance
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('insurance.insurance.create');
    }

    /**
     * Determine if the given user can update the given insurance.
     *
     * @param UserPolicy $user
     * @param Insurance $insurance
     *
     * @return bool
     */
    public function update(UserPolicy $user, Insurance $insurance)
    {
        if ($user->canDo('insurance.insurance.edit') && $user->isAdmin()) {
            return true;
        }

        return $insurance->user_id == user_id() && $insurance->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given insurance.
     *
     * @param UserPolicy $user
     * @param Insurance $insurance
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Insurance $insurance)
    {
        return $insurance->user_id == user_id() && $insurance->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given insurance.
     *
     * @param UserPolicy $user
     * @param Insurance $insurance
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Insurance $insurance)
    {
        if ($user->canDo('insurance.insurance.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given insurance.
     *
     * @param UserPolicy $user
     * @param Insurance $insurance
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Insurance $insurance)
    {
        if ($user->canDo('insurance.insurance.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
