<?php

namespace Superrobota\Insurance\Providers;

use Illuminate\Support\ServiceProvider;

class InsuranceServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'insurance');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'insurance');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('superrobota.insurance', function ($app) {
            return $this->app->make('Superrobota\Insurance\Insurance');
        });

                // Bind Insurance to repository
        $this->app->bind(
            'Superrobota\Insurance\Interfaces\InsuranceRepositoryInterface',
            \Superrobota\Insurance\Repositories\Eloquent\InsuranceRepository::class
        );

        $this->app->register(\Superrobota\Insurance\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Superrobota\Insurance\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['superrobota.insurance'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('superrobota/insurance.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/insurance')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/insurance')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
